@@ -1,7 +1,7 @@
 package Stash::REST;
 use strict;
 use 5.008_005;
-our $VERSION = '0.052';
+our $VERSION = '0.056';
 
 use warnings;
 use utf8;
@@ -281,7 +281,7 @@ sub rest_reload {
     confess 'prepare_request must be a coderef'
       if $prepare_request && ref $prepare_request ne 'CODE';
 
-    my $req = POST $item_url, @headers, [];
+    my $req = GET $item_url, @headers;
     $req->method('GET');
     $prepare_request->($req) if $prepare_request;
 
@@ -341,8 +341,7 @@ sub rest_reload_list {
     confess 'prepare_request must be a coderef'
       if $prepare_request && ref $prepare_request ne 'CODE';
 
-    my $req = POST $item_url, @headers, [];
-    $req->method('GET');
+    my $req = GET $item_url, @headers;
     $prepare_request->($req) if $prepare_request;
 
     $self->call_trigger( 'process_request', { req => $req, conf => \%conf } );
